==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/AssigningScatterStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesStyleEventArgsBaseDescriptionMetadata";
/**
 * @hidden
 */
var AssigningScatterStyleEventArgsBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AssigningScatterStyleEventArgsBaseDescriptionMetadata, _super);
    function AssigningScatterStyleEventArgsBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningScatterStyleEventArgsBaseDescriptionMetadata.b = function (a) {
        if (AssigningScatterStyleEventArgsBaseDescriptionMetadata.a == null) {
            AssigningScatterStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningScatterStyleEventArgsBaseDescriptionMetadata.c(AssigningScatterStyleEventArgsBaseDescriptionMetadata.a);
        }
        if (a.g(AssigningScatterStyleEventArgsBaseDescriptionMetadata.a)) {
            return;
        }
        a.s(AssigningScatterStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningScatterStyleEventArgsBaseDescriptionMetadata.c = function (a) {
        AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningScatterStyleEventArgsBaseDescriptionMetadata.d = function (a) {
        AssigningScatterStyleEventArgsBaseDescriptionMetadata.b(a);
        a.t("AssigningScatterStyleEventArgsBase", AssigningScatterStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningScatterStyleEventArgsBaseDescriptionMetadata.$t = markType(AssigningScatterStyleEventArgsBaseDescriptionMetadata, 'AssigningScatterStyleEventArgsBaseDescriptionMetadata');
    AssigningScatterStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningScatterStyleEventArgsBaseDescriptionMetadata;
}(Base));
export { AssigningScatterStyleEventArgsBaseDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/AssigningScatterStyleEventArgsBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { AssigningSeriesStyleEventArgsBaseDescriptionMetadata } from "./AssigningSeriesStyleEventArgsBaseDescriptionMetadata";
/**
 * @hidden
 */
var AssigningScatterStyleEventArgsBaseDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(AssigningScatterStyleEventArgsBaseDescriptionMetadata, _super);
    function AssigningScatterStyleEventArgsBaseDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    AssigningScatterStyleEventArgsBaseDescriptionMetadata.b = function (a) {
        if (AssigningScatterStyleEventArgsBaseDescriptionMetadata.a == null) {
            AssigningScatterStyleEventArgsBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            AssigningScatterStyleEventArgsBaseDescriptionMetadata.c(AssigningScatterStyleEventArgsBaseDescriptionMetadata.a);
        }
        if (a.j(AssigningScatterStyleEventArgsBaseDescriptionMetadata.a)) {
            return;
        }
        a.y(AssigningScatterStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningScatterStyleEventArgsBaseDescriptionMetadata.c = function (a) {
        AssigningSeriesStyleEventArgsBaseDescriptionMetadata.c(a);
    };
    AssigningScatterStyleEventArgsBaseDescriptionMetadata.d = function (a) {
        AssigningScatterStyleEventArgsBaseDescriptionMetadata.b(a);
        a.z("AssigningScatterStyleEventArgsBase", AssigningScatterStyleEventArgsBaseDescriptionMetadata.a);
    };
    AssigningScatterStyleEventArgsBaseDescriptionMetadata.$t = markType(AssigningScatterStyleEventArgsBaseDescriptionMetadata, 'AssigningScatterStyleEventArgsBaseDescriptionMetadata');
    AssigningScatterStyleEventArgsBaseDescriptionMetadata.a = null;
    return AssigningScatterStyleEventArgsBaseDescriptionMetadata;
}(Base));
export { AssigningScatterStyleEventArgsBaseDescriptionMetadata };
